/*
     This file is part of GNUnet.
     (C) 2001, 2002 Christian Grothoff (and other contributing authors)

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/
/**
 * @file include/util/logging.h
 * @brief Logging service.
 * @author Christian Grothoff
 **/

#ifndef LOGGING_H
#define LOGGING_H

#define LOG_NOTHING    0
#define LOG_FATAL      1
#define LOG_ERROR      2
#define LOG_FAILURE    3
#define LOG_WARNING    4
#define LOG_MESSAGE    5
#define LOG_INFO       6
#define LOG_DEBUG      7
#define LOG_CRON       8
#define LOG_EVERYTHING 9

/* use IFLOG(LOG_XXX, statement(s)) for statements
   that should only be executed if we are at the
   right loglevel */
#define IFLOG(a,b) {if (getLogLevel() >= a) {b;} }

#define PRIP(ip) (ip)>>24, (ip)>>16 & 255, (ip)>>8 & 255, (ip) & 255

/**
 * initialize logging module.
 **/
void initLogging();

/**
 * Re-read the loggig configuration.
 * Call on SIGHUP if the configuration file has changed.
 **/
void resetLogging();

/**
 * Shutdown the logging module.
 **/
void doneLogging();

/**
 * Get the current loglevel.
 **/
int getLogLevel();

/**
 * errexit - log an error message and exit.
 *
 * @param format the string describing the error message
 **/
void errexit(const char *format, ...);

/**
 * Log a message.
 * @param minLogLevel the minimum loglevel that we must be at
 * @param format the format string describing the message
 **/
void LOG(int minLogLevel,
	 const char * format,
	 ...);

#define BREAK() breakpoint_(__FILE__,__LINE__)

/**
 * gdb breakpoint
 **/
void breakpoint_(const char * filename,
                 const int linenumber);

#endif
